summaryrefslogtreecommitdiff
path: root/src/mongo/db/pipeline/document_source_limit.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/pipeline/document_source_limit.h')
-rw-r--r--src/mongo/db/pipeline/document_source_limit.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/src/mongo/db/pipeline/document_source_limit.h b/src/mongo/db/pipeline/document_source_limit.h
index 5105f2fa787..3cecb165cf0 100644
--- a/src/mongo/db/pipeline/document_source_limit.h
+++ b/src/mongo/db/pipeline/document_source_limit.h
@@ -76,14 +76,15 @@ public:
}
/**
* Returns a MergingLogic with two identical $limit stages; one for the shards pipeline and one
* for the merging pipeline.
*/
- boost::optional<MergingLogic> mergingLogic() final {
+ boost::optional<DistributedPlanLogic> distributedPlanLogic() final {
// Running this stage on the shards is an optimization, but is not strictly necessary in
// order to produce correct pipeline output.
// {shardsStage, mergingStage, sortPattern}
- return MergingLogic{this, DocumentSourceLimit::create(pExpCtx, _limit), boost::none};
+ return DistributedPlanLogic{
+ this, DocumentSourceLimit::create(pExpCtx, _limit), boost::none};
}
long long getLimit() const {
@@ -76,14 +76,15 @@ public:
}
/**
- * Returns a MergingLogic with two identical $limit stages; one for the shards pipeline and one
- * for the merging pipeline.
+ * Returns a DistributedPlanLogic with two identical $limit stages; one for the shards pipeline
+ * and one for the merging pipeline.
*/